@@ -14,10 +14,10 @@ use Scalar::Util 'weaken';
 use constant DEBUG => $ENV{MOJO_USERAGENT_DEBUG} || 0;
 
 # "You can't let a single bad experience scare you away from drugs."
-has [qw/app http_proxy https_proxy no_proxy on_start/];
 has cert       => sub { $ENV{MOJO_CERT_FILE} };
 has cookie_jar => sub { Mojo::CookieJar->new };
-has ioloop     => sub { Mojo::IOLoop->new };
+has [qw/http_proxy https_proxy no_proxy on_start/];
+has ioloop => sub { Mojo::IOLoop->new };
 has keep_alive_timeout => 15;
 has key                => sub { $ENV{MOJO_KEY_FILE} };
 has log                => sub { Mojo::Log->new };
@@ -30,6 +30,20 @@ has websocket_timeout => 300;
 # Make sure we leave a clean ioloop behind
 sub DESTROY { shift->_cleanup }
 
+sub app {
+  my ($self, $app) = @_;
+
+  # Try to detect application
+  $self->{app} ||= $ENV{MOJO_APP} if ref $ENV{MOJO_APP};
+  if ($app) {
+    $self->{app} =
+      ref $app ? $app : $self->_test_server->app_class($app)->app;
+    return $self;
+  }
+
+  return $self->{app};
+}
+
 # "Ah, alcohol and night-swimming. It's a winning combination."
 sub build_form_tx      { shift->transactor->form(@_) }
 sub build_tx           { shift->transactor->tx(@_) }
@@ -45,7 +59,7 @@ sub delete {
 sub detect_proxy {
   my $self = shift;
 
-  # Uppercase gets priority
+  # Upper case gets priority
   $self->http_proxy($ENV{HTTP_PROXY}   || $ENV{http_proxy});
   $self->https_proxy($ENV{HTTPS_PROXY} || $ENV{https_proxy});
   if (my $no = $ENV{NO_PROXY} || $ENV{no_proxy}) {
@@ -121,31 +135,13 @@ sub start {
 
 # "It's like my dad always said: eventually, everybody gets shot."
 sub test_server {
-  my ($self, $scheme) = @_;
+  my $self = shift;
 
-  # New test server
-  if ($scheme) {
-    delete $self->{port};
-    delete $self->{server};
-  }
-
-  # Start test server
-  unless ($self->{port}) {
-    my $loop = $self->{loop} || $self->ioloop;
-    my $server = $self->{server} =
-      Mojo::Server::Daemon->new(ioloop => $loop, silent => 1);
-    my $port = $self->{port} = $loop->generate_port;
-    die "Couldn't find a free TCP port for testing.\n" unless $port;
-    $self->{scheme} = $scheme ||= 'http';
-    $server->listen(["$scheme://*:$port"]);
-    $server->prepare_ioloop;
-
-    # Prepare application for testing
-    delete $server->{app};
-    my $app = $self->app;
-    ref $app ? $server->app($app) : $server->app_class($app);
-    $self->log($server->app->log);
-  }
+  # Prepare application for testing
+  my $server = $self->_test_server(@_);
+  delete $server->{app};
+  $server->app($self->app);
+  $self->log($server->app->log);
 
   # Build absolute URL for test server
   return Mojo::URL->new->scheme($self->{scheme})->host('localhost')
@@ -238,10 +234,10 @@ sub _connect {
   weaken $self;
   my $loop = $self->{loop};
   my $id   = $tx->connection;
-  my ($scheme, $address, $port) = $self->_info($tx);
-  $id ||= $self->_cache("$scheme:$address:$port");
+  my ($scheme, $host, $port) = $self->transactor->peer($tx);
+  $id ||= $self->_cache("$scheme:$host:$port");
   if ($id && !ref $id) {
-    warn "KEEP ALIVE CONNECTION ($scheme:$address:$port)\n" if DEBUG;
+    warn "KEEP ALIVE CONNECTION ($scheme:$host:$port)\n" if DEBUG;
     $self->{cs}->{$id} = {cb => $cb, tx => $tx};
     $tx->kept_alive(1);
     $self->_connected($id);
@@ -256,9 +252,9 @@ sub _connect {
     }
 
     # Connect
-    warn "NEW CONNECTION ($scheme:$address:$port)\n" if DEBUG;
+    warn "NEW CONNECTION ($scheme:$host:$port)\n" if DEBUG;
     $id = $loop->connect(
-      address  => $address,
+      address  => $host,
       port     => $port,
       handle   => $id,
       tls      => $scheme eq 'https' ? 1 : 0,
@@ -305,7 +301,7 @@ sub _drop {
   my $c  = delete $self->{cs}->{$id};
   my $tx = $c->{tx};
   if (!$close && $tx && $tx->keep_alive && !$tx->error) {
-    $self->_cache(join(':', $self->_info($tx)), $id)
+    $self->_cache(join(':', $self->transactor->peer($tx)), $id)
       unless (($tx->req->method || '') =~ /^connect$/i
       && ($tx->res->code || '') eq '200');
     return;
@@ -385,24 +381,6 @@ sub _handle {
   $self->{loop}->stop if !$self->{nb} && !$self->{processing};
 }
 
-sub _info {
-  my ($self, $tx) = @_;
-
-  my $req    = $tx->req;
-  my $url    = $req->url;
-  my $scheme = $url->scheme || 'http';
-  my $host   = $url->ihost;
-  my $port   = $url->port;
-  if (my $proxy = $req->proxy) {
-    $scheme = $proxy->scheme;
-    $host   = $proxy->ihost;
-    $port   = $proxy->port;
-  }
-  $port ||= $scheme eq 'https' ? 443 : 80;
-
-  return $scheme, $host, $port;
-}
-
 # "Hey, Weener Boy... where do you think you're going?"
 sub _proxy_connect {
   my ($self, $old, $cb) = @_;
@@ -549,6 +527,30 @@ sub _switch_non_blocking {
   $self->{nb}   = 1;
 }
 
+sub _test_server {
+  my ($self, $scheme) = @_;
+
+  # Fresh start
+  if ($scheme) {
+    delete $self->{port};
+    delete $self->{server};
+  }
+
+  # Start test server
+  unless ($self->{port}) {
+    my $loop = $self->{loop} || $self->ioloop;
+    my $server = $self->{server} =
+      Mojo::Server::Daemon->new(ioloop => $loop, silent => 1);
+    my $port = $self->{port} = $loop->generate_port;
+    die "Couldn't find a free TCP port for testing.\n" unless $port;
+    $self->{scheme} = $scheme ||= 'http';
+    $server->listen(["$scheme://*:$port"]);
+    $server->prepare_ioloop;
+  }
+
+  return $self->{server};
+}
+
 # "Once the government approves something, it's no longer immoral!"
 sub _upgrade {
   my ($self, $id) = @_;
@@ -669,14 +671,6 @@ L<IO::Socket::SSL> are supported transparently and used if installed.
 
 L<Mojo::UserAgent> implements the following attributes.
 
-=head2 C<app>
-
-  my $app = $ua->app;
-  $ua     = $ua->app(MyApp->new);
-
-A Mojo application to associate this user agent with.
-If set, local requests will be processed in this application.
-
 =head2 C<cert>
 
   my $cert = $ua->cert;
@@ -803,6 +797,17 @@ before being dropped, defaults to C<300>.
 L<Mojo::UserAgent> inherits all methods from L<Mojo::Base> and implements the
 following new ones.
 
+=head2 C<app>
+
+  my $app = $ua->app;
+  $ua     = $ua->app('MyApp');
+  $ua     = $ua->app(MyApp->new);
+
+Application relative URLs will be processed with, defaults to the value of
+C<MOJO_APP>.
+
+  print $ua->app->secret;
+
 =head2 C<build_form_tx>
 
   my $tx = $ua->build_form_tx('http://kraih.com/foo' => {test => 123});
